use std::env;
use std::path::PathBuf;

fn main() {
    let manifest_dir = std::env::var("CARGO_MANIFEST_DIR").expect("No CARGO_MANIFEST_DIR");
    println!("cargo:rustc-link-search=native={}", &manifest_dir);

    if std::env::var("CARGO_CFG_TARGET_FAMILY") == Ok(String::from("windows")) {
        let lib_name = if cfg!(debug_assertions) {
            "oo2core_win64_debug"
        } else {
            "oo2core_win64"
        };
        println!("cargo:rustc-link-lib=static={}", lib_name);
    } else {
        println!("cargo:rustc-link-lib=static=oo2corelinux64");
        println!("cargo:rustc-link-lib=stdc++");
    }

    println!("cargo:rerun-if-changed=oodle2.h");

    // The bindgen::Builder is the main entry point
    // to bindgen, and lets you build up options for
    // the resulting bindings.
    let bindings = bindgen::Builder::default()
        // The input header we would like to generate
        // bindings for.
        .header("oodle2base.h")
        .header("oodle2.h")
        .blocklist_file("stdint.h")
        .blocklist_file("stdlib.h")
        // Tell cargo to invalidate the built crate whenever any of the
        // included header files changed.
        .parse_callbacks(Box::new(bindgen::CargoCallbacks::new()))
        // Finish the builder and generate the bindings.
        .generate()
        // Unwrap the Result and panic on failure.
        .expect("Unable to generate bindings");

    // Write the bindings to the $OUT_DIR/bindings.rs file.
    let out_path = PathBuf::from(env::var("OUT_DIR").unwrap());
    bindings
        .write_to_file(out_path.join("bindings.rs"))
        .expect("Couldn't write bindings!");
}
